@@ -22,7 +22,6 @@
 #include <QtGui/QDialog>
 
 class QLabel;
-class QPushButton;
 class QHBoxLayout;
 class QVBoxLayout;
 
@@ -32,7 +31,6 @@ class AboutProgramDialog : public QDialog
 	private:
 		QLabel *iconLabel;
 		QLabel *textLabel;
-		QPushButton *closeButton;
 		QHBoxLayout *topLayout;
 		QHBoxLayout *bottomLayout;
 		QVBoxLayout *mainLayout;
