@@ -25,8 +25,11 @@
 #include <QtGui/QAction>
 #include <QtGui/QComboBox>
 #include <QtGui/QLabel>
+#include <QtGui/QToolButton>
 #include <QtGui/QLineEdit>
+#include <QtGui/QTextBrowser>
 #include <QtCore/QSettings>
+#include <QtCore/QTimer>
 #include "const.h"
 #include "treewidget.h"
 #include "../core/diskcore.h"
@@ -46,6 +49,9 @@ CentralWidget::CentralWidget(DiskCore *diskCore,PopupWindow *popup) {
 	mountWidget = new WidgetForMount(core);
 	mountWidget->hide();
 
+	timer = new QTimer;
+	timer->setInterval(10);
+	
 	// Left widget
 	leftWidget = new QWidget;
 
@@ -73,9 +79,12 @@ CentralWidget::CentralWidget(DiskCore *diskCore,PopupWindow *popup) {
 	treeWidget->addContextMenuAction(setAutomountAction);
 	
 	settingsWidget = new QWidget;
-	settingsWidget->setWhatsThis(tr("Show advanced settings"));
+	settingsWidget->setMaximumHeight(0);
+	rollToUp = false;
+	settingsWidget->show();
 
 	settingsWidgetLayout = new QVBoxLayout;
+	settingsWidgetLayout->addWidget(new QLabel("<b>" + tr("Settings") + "</b>"));
 
 	showTrayMessages = new QCheckBox(tr("Show tray messages"));
 	settingsWidgetLayout->addWidget(showTrayMessages);
@@ -98,9 +107,9 @@ CentralWidget::CentralWidget(DiskCore *diskCore,PopupWindow *popup) {
 	devicesFilter = new QLineEdit;
 	connect(devicesFilter,SIGNAL(textChanged(const QString&)),this,SLOT(setFilter(const QString&)));
 	
-	filterButton = new QPushButton;
+	filterButton = new QToolButton;
 	filterButton->setIcon(QIcon(ICONS_PATH"clear_left.png"));
-	filterButton->setFlat(true);
+	filterButton->setAutoRaise(true);
 	filterButton->setEnabled(false);
 	connect(filterButton,SIGNAL(clicked()),devicesFilter,SLOT(clear()));
 
@@ -113,6 +122,7 @@ CentralWidget::CentralWidget(DiskCore *diskCore,PopupWindow *popup) {
 	settingsWidget->setLayout(settingsWidgetLayout);
 	
 	settingsButton = new QPushButton(tr("Settings"));
+	settingsButton->setToolTip(tr("Show advanced settings"));
 	
 	settingsButtonLayout = new QHBoxLayout;
 	settingsButtonLayout->addWidget(settingsButton);
@@ -133,6 +143,25 @@ CentralWidget::CentralWidget(DiskCore *diskCore,PopupWindow *popup) {
 	
 	stackedWidget = new QStackedWidget;
 	messageBarsArea = new QScrollArea;
+	
+	donationBrowser = new QTextBrowser;
+	donationBrowser->setSource(QUrl(IMAGES_PATH"support_page.html"));
+	donationBrowser->setMaximumHeight(50);
+	supportLabel = new QLabel;
+	supportLabel->setPixmap(QPixmap(IMAGES_PATH"support_image.png"));
+	
+	hideButton = new QPushButton(tr("Hide"));
+	connect(hideButton,SIGNAL(clicked()),donationBrowser,SLOT(hide()));
+	
+	supportButton = new QPushButton(tr("Support Page"));
+	connect(supportButton,SIGNAL(clicked()),this,SIGNAL(goToSupportPage()));
+	
+	QHBoxLayout *browserLayout = new QHBoxLayout;
+	browserLayout->addWidget(supportLabel);
+	browserLayout->addStretch();
+	browserLayout->addWidget(supportButton);
+	browserLayout->addWidget(hideButton);
+	donationBrowser->setLayout(browserLayout);
 
 	rightSplitter->addWidget(stackedWidget);
 	rightSplitter->addWidget(messageBarsArea);
@@ -143,7 +172,8 @@ CentralWidget::CentralWidget(DiskCore *diskCore,PopupWindow *popup) {
 		
 	rightWidgetLayout = new QVBoxLayout;
 	rightWidgetLayout->addWidget(mountWidget);
-	rightWidgetLayout->addWidget(rightSplitter);
+	rightWidgetLayout->addWidget(rightSplitter,1);
+	rightWidgetLayout->addWidget(donationBrowser);
 
 	rightWidget->setLayout(rightWidgetLayout);
 
@@ -169,7 +199,8 @@ CentralWidget::CentralWidget(DiskCore *diskCore,PopupWindow *popup) {
 	treeWidget->resizeColumnToContents(2);
 	checkMessageBars();
 
-	connect(settingsButton,SIGNAL(clicked()),this,SLOT(hideOrShowSettingsWidget()));
+	connect(timer,SIGNAL(timeout()),this,SLOT(updateSettingsWidgetSize()));
+	connect(settingsButton,SIGNAL(clicked()),this,SLOT(showOrHideSettings()));
 	connect(treeWidget,SIGNAL(contextMenuEventSignal()),this,SLOT(showMenu()));
 	connect(treeWidget,SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)),this,SLOT(itemChanged(QTreeWidgetItem*,QTreeWidgetItem*)));
 	connect(core,SIGNAL(deviceAdded(DiskDevice *)),this,SLOT(deviceAdded(DiskDevice *)));
@@ -177,10 +208,12 @@ CentralWidget::CentralWidget(DiskCore *diskCore,PopupWindow *popup) {
 	connect(core,SIGNAL(errorAppeared(const QString &)),this,SLOT(showError(const QString &)));
 	connect(mountAction,SIGNAL(triggered()),this,SLOT(mount()));
 	connect(unmountAction,SIGNAL(triggered()),this,SLOT(unmount()));
-	connect(setAutomountAction,SIGNAL(triggered()),this,SLOT(setAutomount()));
+	connect(setAutomountAction,SIGNAL(triggered()),this,SLOT(setUsbDeviceAutomount()));
 }
 
 CentralWidget::~CentralWidget() {
+	delete timer;
+	
 	delete mountAction;
 	delete unmountAction;
 	delete setAutomountAction;
@@ -198,6 +231,11 @@ CentralWidget::~CentralWidget() {
 	delete leftWidgetLayout;
 	delete leftWidget;
 
+	delete hideButton;
+	delete supportButton;
+	delete supportLabel;
+	delete donationBrowser;
+	
 	delete stackedWidget;
 	delete messageBarsArea;
 	delete mountWidget;
@@ -323,6 +361,7 @@ void CentralWidget::deviceAdded(DiskDevice *addedDevice) {
 		checkMessageBars();
 	}
 	addDevice(addedDevice);
+	emit (deviceWasAdded(addedDevice));
 }
 
 void CentralWidget::removeDevice(DiskDevice *removedDevice) {
@@ -349,6 +388,7 @@ void CentralWidget::removeDevice(DiskDevice *removedDevice) {
 				if (messageBar->device() == removedDevice)
 					messageBar->hide();
 			devices.removeAll(device);
+			emit (deviceWasRemoved(device->diskDevice));
 			return;
 		}
 	}
@@ -409,13 +449,21 @@ void CentralWidget::showError(const QString &errorContent) {
 	showMessage(MessageBar::Error,errorContent);
 }
 
-void CentralWidget::showMessage(int messageType,const QString &messageContent) {
+MessageBar* CentralWidget::showMessage(int messageType,const QString &messageContent) {
 	MessageBar *messageBar = new MessageBar;
 	messageBar->setMessage(messageType,messageContent);
 	areaWidgetLayout->insertWidget(0,messageBar);
 	messageBars.append(messageBar);
 	connect(messageBar,SIGNAL(activated()),this,SLOT(checkMessageBars()));
 	checkMessageBars();
+	
+	return messageBar;
+}
+
+void CentralWidget::showMessageWithActions(const QString& message,const QList<QAction *>& actions) {
+	MessageBar *messageBar = showMessage(0,message);
+	foreach (QAction *action,actions)
+		messageBar->addAction(action);
 }
 
 void CentralWidget::checkMessageBars() {
@@ -432,8 +480,9 @@ void CentralWidget::saveSettings() {
 	QSettings settings(ORGANIZATION,PROGRAM_NAME);
 	settings.setValue("CentralWidget/State",saveState());
 	settings.setValue("CentralWidget/ShowTrayMessages",showTrayMessages->isChecked());
-	settings.setValue("CentralWidget/ShowSettingsWidget",!settingsWidget->isHidden());
+	settings.setValue("CentralWidget/Format",format->currentIndex());
 	settings.setValue("CentralWidget/RightSplitterState",rightSplitter->saveState());
+	settings.setValue("CentralWidget/ShowDonationPanel",donationBrowser->isVisible());
 	emit (finished());
 }
 
@@ -441,12 +490,9 @@ void CentralWidget::loadSettings() {
 	QSettings settings(ORGANIZATION,PROGRAM_NAME);
 	restoreState(settings.value("CentralWidget/State").toByteArray());
 	showTrayMessages->setChecked(settings.value("CentralWidget/ShowTrayMessages",true).toBool());
-	settingsWidget->setVisible(settings.value("CentralWidget/ShowSettingsWidget",false).toBool());
 	rightSplitter->restoreState(settings.value("CentralWidget/RightSplitterState").toByteArray());
-}
-
-void CentralWidget::hideOrShowSettingsWidget() {
-	settingsWidget->setVisible(settingsWidget->isHidden());
+	format->setCurrentIndex(settings.value("CentralWidget/Format").toInt());
+	donationBrowser->setVisible(settings.value("CentralWidget/ShowDonationPanel",true).toBool());
 }
 
 void CentralWidget::showMenu() {
@@ -514,25 +560,15 @@ QString CentralWidget::currentFstabText(bool warn) {
 	return text;
 }
 
-void CentralWidget::setAutomount() {
+void CentralWidget::setUsbDeviceAutomount() {
 	Device *device = currentDevice();
 	DiskDevice *deviceToAutomount = 0;
-	VolumeWidget *volumeWidgetToAutomount = 0;
 	if (device->treeWidgetItem->childCount() > 0) {
 		Device *childDevice = childsForDevice(device->diskDevice).first();
 		deviceToAutomount = childDevice->diskDevice;
-		volumeWidgetToAutomount = childDevice->volumeWidget;
-	} else {
+	} else
 			deviceToAutomount = device->diskDevice;
-			volumeWidgetToAutomount = device->volumeWidget;
-	}
-	if (!volumeWidgetToAutomount)
-		return;
-	if (volumeWidgetToAutomount->mountPoint().isEmpty()) {
-		showError(tr("Mount point of %1 is empty. Choose it to set auto-mount of this device.").arg(deviceToAutomount->blockName()));
-		return;
-	}
-	emit (setAutomountSignal(deviceToAutomount,volumeWidgetToAutomount));
+	emit (setUsbDeviceAutomount(deviceToAutomount));
 }
 
 void CentralWidget::updateCurrentFstabContent() {
@@ -561,3 +597,53 @@ void CentralWidget::setFilter(const QString& filter) {
 	foreach (QTreeWidgetItem *item, treeWidget->findItems(filter,Qt::MatchContains,2))
 		item->setHidden(false);
 }
+
+QList<DiskDevice *> CentralWidget::usbDevices() const {
+	QList<DiskDevice *> usb_devices;
+	foreach (Device *device,devices)
+		if (device->diskDevice->isUsb())
+			usb_devices << device->diskDevice;
+	return usb_devices;
+}
+
+QString CentralWidget::mountOptionsOfDevice(DiskDevice *diskDevice) const {
+	foreach (Device *device,devices)
+		if (device->diskDevice == diskDevice && device->volumeWidget != 0)
+			return device->volumeWidget->options();
+	return QString();
+}
+
+QString CentralWidget::mountPointOfDevice(DiskDevice *diskDevice) const {
+	foreach (Device *device,devices)
+		if (device->diskDevice == diskDevice && device->volumeWidget != 0)
+			return device->volumeWidget->mountPoint();
+	return QString();
+}
+
+void CentralWidget::showOrHideSettings() {
+	rollToUp = !rollToUp;
+	timer->start();
+}
+
+void CentralWidget::updateSettingsWidgetSize() {
+	if (rollToUp) {
+		if (settingsWidget->height() + 10 >= settingsWidget->sizeHint().height())
+			settingsWidget->setMaximumHeight(settingsWidget->sizeHint().height());
+		else
+			settingsWidget->setMaximumHeight(settingsWidget->height() + 10);
+		if (settingsWidget->height() != settingsWidget->sizeHint().height())
+			timer->start();
+		else
+			timer->stop();
+	} else {
+		if (settingsWidget->height() - 10 <= 0)
+			settingsWidget->setMaximumHeight(0);
+		else
+			settingsWidget->setMaximumHeight(settingsWidget->height() - 10);
+		if (settingsWidget->height() != 0)
+			timer->start();
+		else
+			timer->stop();
+	}
+	settingsWidget->resize(settingsWidget->width(),settingsWidget->sizeHint().height());
+}
