@@ -19,11 +19,11 @@
 #ifndef INFOBUTTON_H
 #define INFOBUTTON_H
 
-#include <QPushButton>
+#include <QtGui/QToolButton>
 
 class PopupWindow;
 
-class InfoButton : public QPushButton
+class InfoButton : public QToolButton
 {
 	Q_OBJECT
 	private slots:
